@@ -77,7 +77,10 @@ class Object(object):
         return getattr(self, '_repr_cache')
 
     def todict(self):
-        return self.__dict__
+        data = self.__dict__
+        data.pop('_repr_cache', None)
+
+        return data
 
     def datetime(self, unixtime):
         return datetime.fromtimestamp(int(unixtime))
